@@ -11,7 +11,6 @@
 
 __all__ = ['PyomoMIPConverter']
 
-import coopr.pyomo
 from coopr.opt.base import *
 from pico import PicoMIPConverter
 
@@ -33,22 +32,27 @@ class PyomoMIPConverter(ManagedSingletonPlugin):
 
     def can_convert(self, from_type, to_type):
         """Returns true if this object supports the specified conversion"""
+        if from_type != ProblemFormat.pyomo:
+            return False
         #
         # Return True for specific from/to pairs
         #
-        if from_type == ProblemFormat.pyomo and to_type == ProblemFormat.nl:
+        if to_type in ( ProblemFormat.nl, ProblemFormat.cpxlp,
+                        ProblemFormat.osil ):
             return True
-        if from_type == ProblemFormat.pyomo and to_type == ProblemFormat.cpxlp:
-            return True
-        if self.pico_converter.available() and from_type == ProblemFormat.pyomo and to_type == ProblemFormat.mps:
+
+        if to_type == ProblemFormat.mps and self.pico_converter.available():
             return True
+
         return False
 
-    def apply(self, *args):
+    def apply(self, *args, **kwargs):
         """
         Generate a NL or LP file from Pyomo, and then do subsequent
         conversions.
         """
+        import coopr.pyomo
+        capabilities = kwargs.pop("capabilities", None)
 
         if isinstance(args[2], basestring):
             instance = None
@@ -62,6 +66,7 @@ class PyomoMIPConverter(ManagedSingletonPlugin):
         if args[1] is ProblemFormat.cpxlp:
             problem_filename = pyutilib.services.TempfileManager.create_tempfile(suffix = '.pyomo.lp')
             if instance:
+                instance.has_capability = capabilities
                 (problem_filename, varmap) = instance.write(filename=problem_filename,format=ProblemFormat.cpxlp)
                 return (problem_filename,),None # no map file is necessary
             else:
@@ -80,7 +85,7 @@ class PyomoMIPConverter(ManagedSingletonPlugin):
                 return (problem_filename,),varmap
             #
             # Convert from NL to MPS
-            # 
+            #
             # TBD: We don't support a variable map file when going from NL to MPS within the PICO converter.
             # NOTE: this is a problem with the MPS writer that is provided by COIN-OR
             # NOTE: we should generalize this so it doesn't strictly depend on the PICO converter utility.
@@ -89,3 +94,13 @@ class PyomoMIPConverter(ManagedSingletonPlugin):
             os.remove(problem_filename)
             return ans
 
+        elif args[1] is ProblemFormat.osil:
+            problem_filename = pyutilib.services.TempfileManager.create_tempfile(suffix='pyomo.osil')
+            if instance:
+                (problem_filename, varmap) = instance.write(filename=problem_filename, format=ProblemFormat.osil)
+                return (problem_filename,), None
+            else:
+                msg = 'There is currently no script conversion available from\n'
+                msg += 'Pyomo to OSiL format.'
+
+                raise NotImplementedError, msg
