@@ -12,10 +12,20 @@ import pyutilib.component.core
 pyutilib.component.core.PluginGlobals.push_env( 'coopr.opt' )
 
 from PICO import PICO, MockPICO
-from CBC import CBC, MockCBC
+from CBCplugin import CBC, MockCBC
 from GLPK import GLPK, MockGLPK
 from CPLEX import CPLEX, MockCPLEX
+from CPLEXDirect import CPLEXDirect, MockCPLEXDirect
+from GUROBI import GUROBI
 from ASL import ASL, MockASL
+from ossolver import OSSolver
 #from NLWRITE import NLWRITE
 
+#
+# Interrogate the CBC executable to see if it recognizes the -AMPL flag
+#
+import CBCplugin
+CBCplugin.configure()
+
 pyutilib.component.core.PluginGlobals.pop_env()
+
