@@ -91,7 +91,7 @@ class SolverManager_Pyro(AsynchronousSolverManager):
         data=pyutilib.misc.Bunch(opt=self._opt.type, \
                                  file=problem_file_string, filename=self._opt._problem_files[0], \
                                  warmstart_file=warm_start_file_string, warmstart_filename=warm_start_file_name, \
-                                 kwds=kwds, solver_options=solver_options, mipgap=self._opt.mipgap, suffixes=self._opt.suffixes)
+                                 kwds=kwds, solver_options=solver_options, mipgap=self._opt.mipgap, suffixes=self._opt.suffixes, symbol_map=self._opt._symbol_map)
         task = pyutilib.pyro.Task(data=data, id=ah.id)
         self.client.add_task(task)
         self._ah[task.id] = ah
